@@ -23,8 +23,10 @@
 
 namespace OCA\user_ldap\lib;
 
-//magic properties (incomplete)
+use OC\ServerNotAvailableException;
+
 /**
+ * magic properties (incomplete)
  * responsible for LDAP connections in context with the provided configuration
  *
  * @property string ldapUserFilter
@@ -46,7 +48,7 @@ class Connection extends LDAPUtility {
 	//cache handler
 	protected $cache;
 
-	//settings handler
+	/** @var Configuration settings handler **/
 	protected $configuration;
 
 	protected $doNotValidate = false;
@@ -159,7 +161,8 @@ class Connection extends LDAPUtility {
 			$this->establishConnection();
 		}
 		if(is_null($this->ldapConnectionRes)) {
-			\OCP\Util::writeLog('user_ldap', 'Connection could not be established', \OCP\Util::ERROR);
+			\OCP\Util::writeLog('user_ldap', 'No LDAP Connection to server ' . $this->configuration->ldapHost, \OCP\Util::ERROR);
+			throw new ServerNotAvailableException('Connection to LDAP server could not be established');
 		}
 		return $this->ldapConnectionRes;
 	}
