@@ -57,6 +57,11 @@ try {
 		exit;
 	}
 
+	if (\OC::$server->getSystemConfig()->getValue('singleuser', false)) {
+		\OCP\Util::writeLog('cron', 'We are in admin only mode, skipping cron', \OCP\Util::DEBUG);
+		exit;
+	}
+
 	// load all apps to get all api routes properly setup
 	OC_App::loadApps();
 
@@ -90,6 +95,22 @@ try {
 	}
 
 	if (OC::$CLI) {
+		// the cron job must be executed with the right user
+		if (!OC_Util::runningOnWindows())  {
+			if (!function_exists('posix_getuid')) {
+				echo "The posix extensions are required - see http://php.net/manual/en/book.posix.php" . PHP_EOL;
+				exit(0);
+			}
+			$user = posix_getpwuid(posix_getuid());
+			$configUser = posix_getpwuid(fileowner(OC::$SERVERROOT . '/config/config.php'));
+			if ($user['name'] !== $configUser['name']) {
+				echo "Console has to be executed with the same user as the web server is operated" . PHP_EOL;
+				echo "Current user: " . $user['name'] . PHP_EOL;
+				echo "Web server user: " . $configUser['name'] . PHP_EOL;
+				exit(0);
+			}
+		}
+
 		// Create lock file first
 		TemporaryCronClass::$lockfile = OC_Config::getValue("datadirectory", OC::$SERVERROOT . '/data') . '/cron.lock';
 
