@@ -211,6 +211,7 @@ class Cache {
 	 * @param array $data
 	 *
 	 * @return int file id
+	 * @throws \RuntimeException
 	 */
 	public function put($file, array $data) {
 		if (($id = $this->getId($file)) > -1) {
@@ -248,11 +249,20 @@ class Cache {
 				return trim($item, "`");
 			}, $queryParts);
 			$values = array_combine($queryParts, $params);
-			if (\OC::$server->getDatabaseConnection()->insertIfNotExist('*PREFIX*filecache', $values)) {
+			if (\OC::$server->getDatabaseConnection()->insertIfNotExist('*PREFIX*filecache', $values, [
+				'storage',
+				'path_hash',
+			])) {
 				return (int)\OC_DB::insertid('*PREFIX*filecache');
 			}
 
-			return $this->getId($file);
+			// The file was created in the mean time
+			if (($id = $this->getId($file)) > -1) {
+				$this->update($id, $data);
+				return $id;
+			} else {
+				throw new \RuntimeException('File entry could not be inserted with insertIfNotExist() but could also not be selected with getId() in order to perform an update. Please try again.');
+			}
 		}
 	}
 
@@ -275,10 +285,17 @@ class Cache {
 		}
 
 		list($queryParts, $params) = $this->buildParts($data);
+		// duplicate $params because we need the parts twice in the SQL statement
+		// once for the SET part, once in the WHERE clause
+		$params = array_merge($params, $params);
 		$params[] = $id;
 
-		$sql = 'UPDATE `*PREFIX*filecache` SET ' . implode(' = ?, ', $queryParts) . '=? WHERE `fileid` = ?';
+		// don't update if the data we try to set is the same as the one in the record
+		// some databases (Postgres) don't like superfluous updates
+		$sql = 'UPDATE `*PREFIX*filecache` SET ' . implode(' = ?, ', $queryParts) . '=? ' .
+			'WHERE (' . implode(' <> ? OR ', $queryParts) . ' <> ? ) AND `fileid` = ? ';
 		\OC_DB::executeAudited($sql, $params);
+
 	}
 
 	/**
