@@ -39,6 +39,9 @@ class Updater extends BasicEmitter {
 	/** @var bool */
 	private $updateStepEnabled;
 
+	/** @var bool */
+	private $skip3rdPartyAppsDisable;
+
 	/**
 	 * @param HTTPHelper $httpHelper
 	 * @param IConfig $config
@@ -73,6 +76,16 @@ class Updater extends BasicEmitter {
 		$this->updateStepEnabled = $flag;
 	}
 
+	/**
+	 * Sets whether the update disables 3rd party apps.
+	 * This can be set to true to skip the disable.
+	 *
+	 * @param bool $flag false to not disable, true otherwise
+	 */
+	public function setSkip3rdPartyAppsDisable($flag) {
+		$this->skip3rdPartyAppsDisable = $flag;
+	}
+
 	/**
 	 * Check if a new version is available
 	 *
@@ -172,6 +185,20 @@ class Updater extends BasicEmitter {
 		return true;
 	}
 
+	/**
+	 * Forward messages emitted by the repair routine
+	 *
+	 * @param Repair $repair repair routine
+	 */
+	private function emitRepairMessages(Repair $repair) {
+		$repair->listen('\OC\Repair', 'warning', function ($description) {
+			$this->emit('\OC\Updater', 'repairWarning', array($description));
+		});
+		$repair->listen('\OC\Repair', 'error', function ($description) {
+			$this->emit('\OC\Updater', 'repairError', array($description));
+		});
+	}
+
 	/**
 	 * runs the update actions in maintenance mode, does not upgrade the source files
 	 * except the main .htaccess file
@@ -204,6 +231,7 @@ class Updater extends BasicEmitter {
 
 		// pre-upgrade repairs
 		$repair = new Repair(Repair::getBeforeUpgradeRepairSteps());
+		$this->emitRepairMessages($repair);
 		$repair->run();
 
 		// simulate DB upgrade
@@ -223,6 +251,7 @@ class Updater extends BasicEmitter {
 
 			// post-upgrade repairs
 			$repair = new Repair(Repair::getRepairSteps());
+			$this->emitRepairMessages($repair);
 			$repair->run();
 
 			//Invalidate update feed
@@ -360,9 +389,11 @@ class Updater extends BasicEmitter {
 				continue;
 			}
 
-			// disable any other 3rd party apps
-			\OC_App::disable($app);
-			$this->emit('\OC\Updater', 'thirdPartyAppDisabled', array($app));
+			// disable any other 3rd party apps if not overriden
+			if(!$this->skip3rdPartyAppsDisable) {
+				\OC_App::disable($app);
+				$this->emit('\OC\Updater', 'thirdPartyAppDisabled', array($app));
+			};
 		}
 	}
 
