@@ -317,7 +317,7 @@ class OC_Util {
 	private static function loadVersion() {
 		$timestamp = filemtime(OC::$SERVERROOT . '/version.php');
 		if (!\OC::$server->getSession()->exists('OC_Version') or OC::$server->getSession()->get('OC_Version_Timestamp') != $timestamp) {
-			require 'version.php';
+			require OC::$SERVERROOT . '/version.php';
 			$session = \OC::$server->getSession();
 			/** @var $timestamp int */
 			$session->set('OC_Version_Timestamp', $timestamp);
@@ -577,7 +577,7 @@ class OC_Util {
 				'DOMDocument' => 'dom',
 				'XMLWriter' => 'XMLWriter'
 			),
-			'functions' => array(
+			'functions' => [
 				'xml_parser_create' => 'libxml',
 				'mb_detect_encoding' => 'mb multibyte',
 				'ctype_digit' => 'ctype',
@@ -586,8 +586,8 @@ class OC_Util {
 				'gzencode' => 'zlib',
 				'iconv' => 'iconv',
 				'simplexml_load_string' => 'SimpleXML',
-				'hash' => 'HASH Message Digest Framework'
-			),
+				'hash' => 'HASH Message Digest Framework',
+			],
 			'defined' => array(
 				'PDO::ATTR_DRIVER_NAME' => 'PDO'
 			)
@@ -628,25 +628,6 @@ class OC_Util {
 			$webServerRestart = true;
 		}
 
-		/**
-		 * PHP 5.6 ships with a PHP setting which throws notices by default for a
-		 * lot of endpoints. Thus we need to ensure that the value is set to -1
-		 *
-		 * FIXME: Due to https://github.com/owncloud/core/pull/13593#issuecomment-71178078
-		 * this check is disabled for HHVM at the moment. This should get re-evaluated
-		 * at a later point.
-		 *
-		 * @link https://github.com/owncloud/core/issues/13592
-		 */
-		if(version_compare(phpversion(), '5.6.0', '>=') &&
-			!self::runningOnHhvm() &&
-			\OC::$server->getIniWrapper()->getNumeric('always_populate_raw_post_data') !== -1) {
-			$errors[] = array(
-				'error' => $l->t('PHP is configured to populate raw post data. Since PHP 5.6 this will lead to PHP throwing notices for perfectly valid code.'),
-				'hint' => $l->t('To fix this issue set <code>always_populate_raw_post_data</code> to <code>-1</code> in your php.ini')
-			);
-		}
-
 		if (!self::isAnnotationsWorking()) {
 			$errors[] = array(
 				'error' => $l->t('PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible.'),
