@@ -11,8 +11,7 @@ $appId = $_POST['appid'];
 $appId = OC_App::cleanAppId($appId);
 
 // FIXME: Clear the cache - move that into some sane helper method
-\OC::$server->getMemCacheFactory()->create('settings')->remove('listApps-0');
-\OC::$server->getMemCacheFactory()->create('settings')->remove('listApps-1');
+\OC::$server->getMemCacheFactory()->create('settings')->clear('listApps-');
 
 OC_App::disable($appId);
 OC_JSON::success();
